#!/bin/sh

# set the needed environment variables
#../environment_variables
PW_ROOT="/opt/QE61/bin"
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
TMP_DIR="/home/jyhuang/WS_QE/scratch"

####################################################################
# define some QE variables (do not change)
precmd="mpirun -np 12 --map-by core"
#pseudo=pbe-nd-rrkjus
pseudo=gpbe-n-campos.uspp
name=Fe
struct=bcc.FM
####################################################################
# define some QE variables to play with
nK=10
degauss=0.005

rm -rf results.alat
mkdir results.alat

cd results.alat

rm -f $name.$struct.scf.out

for lattice_const in  2.5 2.6 2.7 2.8 2.9 3.0 3.1 3.2  ; do
# scf calculation
cat >  $name.$struct.scf.in << EOF
 &control
    calculation = 'scf' ,
    restart_mode = 'from_scratch' ,
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
 /
 &system
    ibrav = 3,
    a=$lattice_const,
    nat= 1,
    ntyp= 1,
    nspin = 2,
    ecutwfc = 35,
    ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
 $name 0.0 0.0 0.0
K_POINTS automatic
 $nK $nK $nK 0 0 0
EOF

$precmd $PW_ROOT/pw.x < $name.$struct.scf.in >> $name.$struct.scf.out

done

cat>>$name.$struct.etot_vs_lattice <<EOF1
@#  alat  Etot  nK=$nK  degauss=$degauss
EOF1

cat>>$name.$struct.mag_vs_lattice <<EOF2
@#  alat  M   nK=$nK  degauss=$degauss
EOF2

grep -e 'lattice parameter' -e ! $name.$struct.scf.out | awk '/lattice parameter/{lattice=$(NF-1)}/!/{print lattice, $(NF-1)}' >> $name.$struct.etot_vs_lattice

grep -e 'lattice parameter' -e 'total magnetization' $name.$struct.scf.out |\
 awk '{if($1=="lattice"){i=i+1;lattice[i]=$(NF-1)} else {mag[i]=$(NF-2)} } END{for (j=1;j<=i;j++) {printf "\t" lattice[j] "\t" mag[j] "\n" }}'  >> $name.$struct.mag_vs_lattice
