#!/bin/sh
####################################################################
# set the needed environment variables
PW_ROOT="/opt/QE61/bin"
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
TMP_DIR="/home/jyhuang/WS_QE/scratch"
PLOTBAND_COMMAND="/opt/QE61/bin/plotband.x"
####################################################################
# define some QE variables (do not change)
precmd="mpirun -np 12 --map-by core"
pseudo=gpbe-n-campos.uspp
name=Fe
struct=bccFM
lattice_const=2.85
nK=20
degauss=0.005 # unit: Ry

rm -rf results.band
mkdir results.band

cd results.band

# scf calculation
cat >  $name.$struct.scf.in << EOF1
 &control
    calculation = 'scf' ,
    restart_mode = 'from_scratch' ,
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
 /
 &system
    ibrav = 3,
    a =$lattice_const,
    nat= 1,
    ntyp= 1,
    nspin = 2,
    ecutwfc = 35,
    ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
 $name 0.0 0.0 0.0
K_POINTS automatic
 $nK $nK $nK 0 0 0
EOF1

$precmd $PW_ROOT/pw.x < $name.$struct.scf.in > $name.$struct.scf.out

# Check the Fermi energy
grep -e "the Fermi energy" $name.$struct.scf.out
echo -n "Enter the Fermi energy> "
read Ef

# band calculation
cat > $name.$struct.bands.in << EOF2
 &control
    calculation='bands'
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    verbosity='high'
 /
 &system
    ibrav = 3,
    a =$lattice_const,
    nat= 1,
    ntyp= 1,
    nbnd=7,
    nspin = 2,
    ecutwfc = 35,
    ecutrho = 350.0,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.3
 /
ATOMIC_SPECIES
 $name 55.847  $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
 $name 0.0 0.0 0.0
K_POINTS (tpiba_b)
6
0.0 0.0 0.0  20  # G
0.5 0.5 0.0  20  # N
0.5 0.5 0.5  20  # H
0.0 0.0 0.0  20  # G
0.0 1.0 0.0  20  # P
0.5 0.5 0.0  1   # N
EOF2

$precmd $PW_ROOT/pw.x < $name.$struct.bands.in > $name.$struct.bands.out

# Check the max abd min energies
grep -e "SPIN UP" $name.$struct.bands.out -A 6
echo -n "Enter the min band energy> "
read Emin
echo -n "Enter the max band energy> "
read Emax

cat > bands.in << EOF3
 &bands
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    filband='$name.$struct.bands.up'
    spin_component= 1
    lsym=.true.
 /
EOF3

$precmd $PW_ROOT/bands.x < bands.in > bands.up.out

rm -f bands.in
cat >  bands.in << EOF4
 &bands
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    filband='$name.$struct.bands.dn'
    spin_component= 2
    lsym=.true.
 /
EOF4

$precmd $PW_ROOT/bands.x < bands.in > bands.dn.out

##### Plotting the band dispersions with plotband.x module
Xl=$(echo "$Emin-1" |bc)
###
#  Make files for plotting the band dispersions
cat > plotband.in <<EOF5
$name.$struct.bands.up
$Emin $Emax
$name.$struct.bands.up.xmgr
$name.$struct.bands.up.eps
$Ef
1.0, $Ef
EOF5
#
$PLOTBAND_COMMAND < plotband.in
#
cat $name.$struct.bands.up.xmgr.1.* $name.$struct.bands.up.xmgr.2.* $name.$struct.bands.up.xmgr.3.* \
$name.$struct.bands.up.xmgr.4.* $name.$struct.bands.up.xmgr.5.* >> $name.$struct.bands.up.xmgr
rm -rf $name.$struct.bands.up.xmgr.*.*
#
cat > plotband.in <<EOF6
$name.$struct.bands.dn
$Emin $Emax
$name.$struct.bands.dn.xmgr
$name.$struct.bands.dn.eps
$Ef
1.0, $Ef
EOF6
#
$PLOTBAND_COMMAND < plotband.in > plotband.out
#
cat $name.$struct.bands.dn.xmgr.1.* $name.$struct.bands.dn.xmgr.2.* $name.$struct.bands.dn.xmgr.3.* \
$name.$struct.bands.dn.xmgr.4.* $name.$struct.bands.dn.xmgr.5.* >> $name.$struct.bands.dn.xmgr
rm -rf $name.$struct.bands.dn.xmgr.*.*

# Range:    4.5560   39.1900eV  Emin, Emax >
# high-symmetry point:  0.0000 0.0000 0.0000   x coordinate   0.0000 G
# high-symmetry point:  0.5000 0.5000 0.0000   x coordinate   0.7071 N
# high-symmetry point:  0.5000 0.5000 0.5000   x coordinate   1.2071 H
# high-symmetry point:  0.0000 0.0000 0.0000   x coordinate   2.0731 P
# high-symmetry point:  0.0000 1.0000 0.0000   x coordinate   3.0731 G
# high-symmetry point:  0.5000 0.5000 0.0000   x coordinate   3.7802 N
# make gnuplot for the dispersion
#
cat > plot_bandstr.gnu <<EOF7
set terminal post eps enhanced solid color "Helvetica" 20
set output "$name.$struct.bandstr.eps"
set key off

set xrange [0:3.8]
set yrange [$Emin:$Emax]

set arrow from 0.71, $Emin to 0.71, $Emax nohead  lw 3
set arrow from 1.21, $Emin to 1.21, $Emax nohead  lw 3
set arrow from 2.07, $Emin to 2.07, $Emax nohead  lw 3
set arrow from 3.07, $Emin to 3.07, $Emax nohead  lw 3
set arrow from 0., $Ef to 3.8, $Ef nohead lw 1

set ylabel "E (eV)"
unset xtics
set label "{/Symbol G}" at -0.05, $Xl
set label "N" at 0.65, $Xl
set label "H" at 1.16, $Xl
set label "P" at 2.02, $Xl
set label "G" at 3.02, $Xl
set label "N" at 3.73, $Xl

plot "$name.$struct.bands.up.xmgr" u 1:2 w l lt 1 lc 1 lw 1,\
"$name.$struct.bands.dn.xmgr" u 1:2 w l lt 3 lc 3 lw 1
EOF7

#plot everything and convert it to png
#
gnuplot plot_bandstr.gnu
../../../scripts/eps2png $name.$struct.bandstr.eps $name.$struct.bandstr.png
