#!/bin/sh
####################################################################
# set the needed environment variables
PW_ROOT="/opt/QE61/bin"
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
TMP_DIR="/home/jyhuang/WS_QE/scratch"
####################################################################
# define some QE variables (do not change)
precmd="mpirun -np 12 --map-by core"
pseudo=gpbe-n-campos.uspp
name=Fe
struct=bccFM
lattice_const=2.85
nK=15
nKdos=20
degauss=0.01

rm -rf results.dos
mkdir results.dos
cd results.dos

rm -f $name.$struct.scf.out

# scf calculation
cat >  $name.$struct.scf.in << EOF1
 &control
    calculation = 'scf' ,
    restart_mode = 'from_scratch' ,
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
 /
 &system
    ibrav = 3,
    a =$lattice_const,
    nat= 1,
    ntyp= 1,
    nspin = 2,
    ecutwfc = 35,
    ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
 $name 0.0 0.0 0.0
K_POINTS automatic
 $nK $nK $nK 0 0 0
EOF1

$precmd $PW_ROOT/pw.x < $name.$struct.scf.in > $name.$struct.scf.out
# Check the Fermi energy
grep -e "the Fermi energy" $name.$struct.scf.out
echo -n "Enter the Fermi energy> "
read Ef

# nscf calculation
cat >  $name.$struct.nscf.in << EOF2
 &control
    calculation='nscf'
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    verbosity='high'
/
 &system
    ibrav = 3,
    a =$lattice_const,
    nat= 1,
    ntyp= 1,
    nbnd=7,
    nspin = 2,
    ecutwfc = 35, ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
 $name 0.0 0.0 0.0
K_POINTS automatic
 $nKdos $nKdos $nKdos 0 0 0
EOF2

$precmd $PW_ROOT/pw.x < $name.$struct.nscf.in > $name.$struct.nscf.out

# Check the max abd min energies
grep -e "SPIN UP" $name.$struct.nscf.out -A 6
echo -n "Enter the min band energy> "
read Emin
echo -n "Enter the max band energy> "
read Emax

# dos calculation
cat > dos.in << EOF3
&dos
    outdir='$TMP_DIR/' ,
    prefix='$name.$struct' ,
    fildos='$name.$struct.dos',
    ngauss= 0,
    degauss= $degauss,
    Emin=$Emin,
    Emax=$Emax,
    DeltaE=0.1 ! energy grid step (eV)
 /
EOF3

$precmd $PW_ROOT/dos.x < dos.in > dos.out

cat > dos.gnu << EOF4
#!/usr/bin/gnuplot
set terminal postscript eps color solid "Helvetica" 26
set output "$name.$struct.dos.eps"
set zero 1e-18

set xlabel "E [eV]"
set ylabel "DOS"
set xrange [$Emin:$Emax]
set yrange [0:3]
set arrow from $Ef,0 to $Ef,3 nohead lw 2

plot "$name.$struct.dos" using 1:2 title "Up DoS" w l lt 1 lc 1 lw 1,\
"$name.$struct.dos" using 1:3 title 'Down DoS' w l lt 3 lc 3 lw 1
EOF4
#### Plotting
gnuplot dos.gnu
../../../scripts/eps2png $name.$struct.dos.eps $name.$struct.dos.png

# pdos calculation
cat >  projwfc.in << EOF5
 &projwfc
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    ngauss=0
    degauss=$degauss
    Emin=$Emin
    Emax=$Emax
    DeltaE=0.1
    filpdos='$name.$struct.pdos'
 /
EOF5

$precmd $PW_ROOT/projwfc.x < projwfc.in > projwfc.out

cat > pdos.gnu << EOF6
#!/usr/bin/gnuplot
set terminal postscript eps color solid "Helvetica" 26 
set output "$name.$struct.pdos.eps"
set zero 1e-18

set xlabel "E [eV]"
set ylabel "PDOS"

set xrange [$Emin:$Emax]
set yrange [0:1.2]
set arrow from $Ef,0 to $Ef,1.2 nohead lw 2

plot "$name.$struct.pdos.pdos_atm#1(Fe)_wfc#2(s)" using 1:4 t "Fe:s-Up" w l lt 1 lc 1 lw 1,\
"$name.$struct.pdos.pdos_atm#1(Fe)_wfc#3(p)" using 1:4 t "Fe:p-Up" w l lt 1 lc 3 lw 1,\
"$name.$struct.pdos.pdos_atm#1(Fe)_wfc#1(d)" using 1:4 t "Fe:d-Up" w l lt 1 lc 4 lw 1,\
"$name.$struct.pdos.pdos_atm#1(Fe)_wfc#2(s)" using 1:5 t "s-Down" w l lt 3 lc 1 lw 2,\
"$name.$struct.pdos.pdos_atm#1(Fe)_wfc#3(p)" using 1:5 t "p-Down" w l lt 3 lc 3 lw 2,\
"$name.$struct.pdos.pdos_atm#1(Fe)_wfc#1(d)" using 1:5 t "d-Down" w l lt 3 lc 4 lw 2
EOF6
#### Plotting
gnuplot pdos.gnu
../../../scripts/eps2png $name.$struct.pdos.eps $name.$struct.pdos.png
