#!/bin/sh
# set the needed environment variables
#../environment_variables
PW_ROOT="/opt/QE61/bin"
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
TMP_DIR="/home/jyhuang/WS_QE/scratch"

####################################################################
# define some QE variables
precmd="mpirun -np 12 --map-by core"
pseudo=gpbe-n-campos.uspp
name=Fe
struct=bcc.surf001.FM
lattice_const=2.85
nK=7
degauss=0.005
nKdos=15

rm -rf results.charge-density
mkdir results.charge-density

cd results.charge-density

rm -f $name.$struct.scf.out

# scf calculation
cat >  $name.$struct.scf.in << EOF
 &control
    calculation = 'scf' ,
    restart_mode = 'from_scratch' ,
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
 /
 &system
    ibrav = 6,
    a =$lattice_const,
    c=14 ,
    nat= 5,
    ntyp= 1,
    nspin = 2,
    nbnd=35
    ecutwfc = 35,
    ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7
    mixing_mode='local-TF'
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
$name   0.000000000000000  0.000000000000000   -1.0000000000000000
$name   0.500000000000000  0.500000000000000   -0.5000000000000000
$name   0.000000000000000  0.000000000000000    0.0000001000000000
$name   0.500000000000000  0.500000000000000    0.5000000000000000
$name   0.000000000000000  0.000000000000000    1.0000000000000000
K_POINTS automatic
 $nK $nK 1 0 0 0
EOF

$precmd $PW_ROOT/pw.x < $name.$struct.scf.in > $name.$struct.scf.out

# nscf calculation
cat >  $name.$struct.nscf.in << EOF
 &control
    calculation='nscf'
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
 /
 &system
    ibrav = 6,
    a =$lattice_const,
    c=14 ,
    nat= 5,
    ntyp= 1,
    nspin = 2,
    nbnd=35,
    ecutwfc = 35,
    ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
$name   0.000000000000000  0.000000000000000   -1.0000000000000000
$name   0.500000000000000  0.500000000000000   -0.5000000000000000
$name   0.000000000000000  0.000000000000000    0.0000001000000000
$name   0.500000000000000  0.500000000000000    0.5000000000000000
$name   0.000000000000000  0.000000000000000    1.0000000000000000
K_POINTS automatic
 $nKdos $nKdos 1  0 0 0
EOF

$precmd $PW_ROOT/pw.x < $name.$struct.nscf.in > $name.$struct.nscf.out

# post-processing
cat >  $name.$struct.pp.in << EOF
 &inputpp
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    filplot='$name.$struct.charge-density.up'
    plot_num=0
    spin_component=1
 /
 &plot
    iflag=1
    e1(1)=0
    e1(2)=0
    e1(3)=-5
    x0(1)=0
    x0(2)=0
    x0(3)=0    
    nx=100
    output_format=0
    fileout='$name.$struct.charge-density.plot.up'
  /
EOF

$precmd $PW_ROOT/pp.x < $name.$struct.pp.in > $name.$struct.pp.out

# post-processing
cat >  $name.$struct.pp.in << EOF
 &inputpp
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    filplot='$name.$struct.charge-density.dn'
    plot_num=0
    spin_component=2
 /
 &plot
    iflag=1
    e1(1)=0
    e1(2)=0
    e1(3)=-5
    x0(1)=0
    x0(2)=0
    x0(3)=0
    nx=100
    output_format=0
    fileout='$name.$struct.charge-density.plot.dn'
  /
EOF

$precmd $PW_ROOT/pp.x < $name.$struct.pp.in > $name.$struct.pp.out
