#!/bin/sh
####################################################################
# set the needed environment variables
#../environment_variables
PW_ROOT="/opt/QE61/bin"
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
TMP_DIR="/home/jyhuang/WS_QE/scratch"

####################################################################
# define some QE variables
precmd="mpirun -np 12 --map-by core"
pseudo=gpbe-n-campos.uspp
name=Fe
struct=bcc.surf001.FM
lattice_const=2.85
nK=7
degauss=0.005
nKdos=15

rm -rf results.dos
mkdir results.dos

cd results.dos

rm -f $name.$struct.scf.out

# scf calculation
cat >  $name.$struct.scf.in << EOF
 &control
    calculation = 'scf',
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
 /
 &system
    ibrav = 6,
    a =$lattice_const,
    c=14 ,
    nat= 5,
    ntyp= 1,
    nspin = 2,
    nbnd=35
    ecutwfc = 35,
    ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7
    mixing_mode='local-TF'
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
$name   0.000000000000000  0.000000000000000   -1.0000000000000000
$name   0.500000000000000  0.500000000000000   -0.5000000000000000
$name   0.000000000000000  0.000000000000000    0.0000001000000000
$name   0.500000000000000  0.500000000000000    0.5000000000000000
$name   0.000000000000000  0.000000000000000    1.0000000000000000
K_POINTS automatic
 $nK $nK 1  0 0 0
EOF

$precmd $PW_ROOT/pw.x < $name.$struct.scf.in > $name.$struct.scf.out

# nscf calculation
cat >  $name.$struct.nscf.in << EOF
 &control
    calculation='nscf'
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
 /
 &system
    ibrav = 6,
    a =$lattice_const,
    c=14 ,
    nat= 5,
    ntyp= 1,
    nspin = 2,
    nbnd=35,
    ecutwfc = 35,
    ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    occupations='smearing',
    smearing='MV',
    degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
$name   0.000000000000000  0.000000000000000   -1.0000000000000000
$name   0.500000000000000  0.500000000000000   -0.5000000000000000
$name   0.000000000000000  0.000000000000000    0.0000001000000000
$name   0.500000000000000  0.500000000000000    0.5000000000000000
$name   0.000000000000000  0.000000000000000    1.0000000000000000
K_POINTS automatic
 $nKdos $nKdos 1  0 0 0
EOF

$precmd $PW_ROOT/pw.x < $name.$struct.nscf.in > $name.$struct.nscf.out

# pdos calculation
cat >  $name.$struct.projwfc.in << EOF
 &projwfc
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
    ngauss=0
    degauss=0.005
    Emin=-5
    Emax=10
    DeltaE=0.1
    filpdos='$name.$struct.pdos'
 /
EOF

$precmd $PW_ROOT/projwfc.x < $name.$struct.projwfc.in > $name.$struct.projwfc.out
