#!/bin/sh
# set the needed environment variables
PW_ROOT="/opt/QE61/bin"
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
TMP_DIR="/home/jyhuang/WS_QE/scratch"

####################################################################
# define some QE variables
precmd="mpirun -np 12 --map-by core"

pseudo=rel_LDA.RRKJ3
name=Fe
struct=wire.FM.soc
nK=100
degauss=0.005

rm -rf results.aniso.alat
mkdir results.aniso.alat

cd results.aniso.alat

rm -f $name.$struct.scf.out

for theta in 0.0 90.0 ; do
for d in 2.0  2.40   ;do
# scf calculation
cat >  $name.$struct.scf.in << EOF
 &control
    calculation = 'scf' ,
    pseudo_dir = '$PSEUDO_DIR/',
    outdir='$TMP_DIR/'
    prefix='$name.$struct'
 /
 &system
    ibrav = 6, a =5, c=$d ,nat= 1, ntyp= 1,
    noncolin=.true.
    lspinorb=.true.   
    ecutwfc = 35, ecutrho = 350.0,
    starting_magnetization(1)=0.3,
    angle1(1)=$theta
    angle2(1)=0
    occupations='smearing', smearing='MV', degauss=$degauss
 /
 &electrons
    conv_thr = 1.0e-8
    mixing_beta = 0.7   
 /
ATOMIC_SPECIES
$name 55.847 $name.$pseudo.UPF
ATOMIC_POSITIONS {alat}
$name   0.000000000000000  0.000000000000000   0.0000000000000000
K_POINTS automatic
 1 1 $nK 0 0 0
EOF

$precmd $PW_ROOT/pw.x < $name.$struct.scf.in >> $name.$struct.scf.theta$theta.out
done

cat>>$name.$struct.etot_vs_lattice <<EOF1
@#  alat  Etot  theta=$theta
EOF1

grep -e 'lattice parameter' -e ! $name.$struct.scf.theta$theta.out | \
      awk '/lattice parameter/{lattice=$(NF-1)}/!/{print lattice, $(NF-1)}' >> $name.$struct.etot_vs_lattice

done
